'use strict';

/*eslint-env browser*/
var React = require('react');
var PropTypes = require('prop-types');
var update = require('immutability-helper');

var base64DataForFile = function base64DataForFile(file) {
  return new window.Promise(function (resolve, reject) {
    var reader = new window.FileReader();
    reader.onload = function (result) {
      var data = result && result.target && result.target.result;
      data ? resolve(data) : reject();
    };
    reader.readAsDataURL(file);
  });
};

var Image = function Image(_ref) {
  var data = _ref.data,
      isEditing = _ref.isEditing,
      updateData = _ref.updateData;
  return isEditing ? React.createElement(
    'div',
    null,
    React.createElement('input', {
      accept: 'image/*',
      className: 'blurb blurb-image-src-editing',
      type: 'file',
      onChange: function onChange(event) {
        var file = event.target.files[0]; // Only allow for single file selection
        if (file) {
          base64DataForFile(file).then(function (srcData) {
            return updateData(update(data, { srcData: { $set: srcData } }));
          });
        }
      },
      onClick: function onClick(event) {
        return event.target.value = null;
      } }),
    React.createElement('input', {
      autoFocus: false,
      className: 'blurb blurb-image-alt-editing',
      type: 'text',
      placeholder: 'alt text',
      value: data.alt,
      onChange: function onChange(event) {
        return updateData(update(data, { alt: { $set: event.target.value } }));
      } }),
    React.createElement('input', {
      autoFocus: false,
      className: 'blurb blurb-image-href-editing',
      type: 'text',
      placeholder: 'link',
      value: data.href,
      onChange: function onChange(event) {
        return updateData(update(data, { href: { $set: event.target.value } }));
      } })
  ) : data.href ? React.createElement(
    'a',
    { href: data.href },
    React.createElement('img', {
      alt: data.alt,
      className: 'blurb blurb-image',
      src: data.src })
  ) : React.createElement('img', {
    alt: data.alt,
    className: 'blurb blurb-image',
    src: data.src });
};

Image.propTypes = {
  data: PropTypes.shape({
    alt: PropTypes.string,
    src: PropTypes.string,
    href: PropTypes.string
  }),
  isEditing: PropTypes.bool,
  updateData: PropTypes.func
};

module.exports = Image;